/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// fpm.i: SWIG input file of the fpm python interface

%feature("autodoc","1");

%module(docstring=
"'fpmw' module: field panel method
(c) ULg - A&M",
directors="1",
threads="1"
) fpmw
%{

//#if defined(_WIN32) && defined(__GNUC__)
#undef _hypot
#include <cmath>
//#endif

#include <memory>
#include <string>
#include <sstream>
#include <typeinfo>

#include "fwkw.h"
#include "tboxw.h"
#include "fpmw.h"

#include "fpm.h"

%}

%include "fwkw.swg"
%import "tboxw.i"

%include "fpm.h"

%include "fTimers.h"

namespace fpm {
%extend Timers {
    Timer &getitem(std::string const &name)
    {
        return (*self)[name];
    }

    %pythoncode {
def __getitem__(self, name):
    return self.getitem(name)
    }
}
};

%include <std_shared_ptr.i>

%shared_ptr(fpm::Field);
%include "fField.h"

%shared_ptr(fpm::Body);
%immutable fpm::Body::wake; // avoids the creation of the setter method
%include "fBody.h"
%shared_ptr(fpm::Wake);
%include "fWake.h"

%shared_ptr(fpm::Problem);
%immutable fpm::Problem::msh;
%include "fProblem.h"

%shared_ptr(fpm::Builder);
%immutable fpm::Builder::pbl;
%include "fBuilder.h"

%shared_ptr(fpm::Solver);
%immutable fpm::Solver::aic;
%include "fSolver.h"
